@@ -114,7 +114,7 @@ extern void cha_print_ctype_table();
 extern void cha_print_cform_table();
 
 /* parse.c */
-extern void take_data();
+extern void get_mrph_data();
 extern int chasen_sent();
 
 /* chalib.c */
